
from . import cookiesapi_client

__all__ = [
    'api_helper',
    'configuration',
    'controllers',
    'cookiesapi_client',
    'decorators',
    'exceptions',
    'http',
    'models',
]


## Entrypoint
CookiesSDK = cookiesapi_client.CookiesapiClient



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Name(object):

    """Implementation of the 'Name' model.

    Generic name, with an alternative label.

    Attributes:
        label (string): Display label.
        alt (string): Alternate display label.
        primary (string): Primary name.
        display (string): Display name for this record. Overrides all other
            names.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "label": 'label',
        "alt": 'alt',
        "primary": 'primary',
        "display": 'display'
    }

    def __init__(self,
                 label=None,
                 alt=None,
                 primary=None,
                 display=None):
        """Constructor for the Name class"""

        # Initialize members of the class
        self.label = label
        self.alt = alt
        self.primary = primary
        self.display = display

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        label = dictionary.get('label')
        alt = dictionary.get('alt')
        primary = dictionary.get('primary')
        display = dictionary.get('display')

        # Return an object of this model
        return cls(label,
                   alt,
                   primary,
                   display)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Phone(object):

    """Implementation of the 'Phone' model.

    Specifies phone-based contact information.

    Attributes:
        e_164 (string): E164-formatted phone number.
        display (string): National display format for the number.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "e_164": 'e164',
        "display": 'display'
    }

    def __init__(self,
                 e_164=None,
                 display=None):
        """Constructor for the Phone class"""

        # Initialize members of the class
        self.e_164 = e_164
        self.display = display

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        e_164 = dictionary.get('e164')
        display = dictionary.get('display')

        # Return an object of this model
        return cls(e_164,
                   display)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TimeSpec(object):

    """Implementation of the 'TimeSpec' model.

    Specifies a place in time in relative terms to the start of a given day.

    Attributes:
        hours (int): Hours value for this time specification.
        minutes (string): Minutes value for this time specification.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "hours": 'hours',
        "minutes": 'minutes'
    }

    def __init__(self,
                 hours=None,
                 minutes=None):
        """Constructor for the TimeSpec class"""

        # Initialize members of the class
        self.hours = hours
        self.minutes = minutes

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        hours = dictionary.get('hours')
        minutes = dictionary.get('minutes')

        # Return an object of this model
        return cls(hours,
                   minutes)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StrainSocial(object):

    """Implementation of the 'StrainSocial' model.

    Describes social media properties for a given strain.

    Attributes:
        review_count (int): Count of available reviews for this strain.
        review_rating (int): Average rating for this strain, across available
            public reviews.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "review_count": 'reviewCount',
        "review_rating": 'reviewRating'
    }

    def __init__(self,
                 review_count=None,
                 review_rating=None):
        """Constructor for the StrainSocial class"""

        # Initialize members of the class
        self.review_count = review_count
        self.review_rating = review_rating

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        review_count = dictionary.get('reviewCount')
        review_rating = dictionary.get('reviewRating')

        # Return an object of this model
        return cls(review_count,
                   review_rating)



__all__ = [
    'store_list',
    'store',
    'store_key',
    'name',
    'location',
    'address',
    'geo',
    'contact',
    'phone',
    'hours',
    'regular_hours',
    'hours_range',
    'time_spec',
    'store_social',
    'social_property',
    'store_media',
    'media_item',
    'media_key',
    'media_type',
    'store_web',
    'store_branding',
    'first_party_branding',
    'store_ordering',
    'stores_request',
    'error_info',
    'error_detail',
    'strain_list',
    'strain',
    'brand_spec',
    'brand',
    'dual_format_graphic',
    'responsive_graphic',
    'theme',
    'strain_media',
    'material_info',
    'breeder',
    'color',
    'strain_social',
    'brand_asset',
    'raster_graphic',
    'brand_list',
    'cookies_brand_enum',
    'store_type_enum',
    'store_status_enum',
    'store_capability_enum',
    'species_enum',
]



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.social_property import SocialProperty


class StoreSocial(object):

    """Implementation of the 'StoreSocial' model.

    Social media information for a first-party Cookies store.

    Attributes:
        property (list of SocialProperty): Social media properties.
        facebook_user (string): Store Facebook page username.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "property": 'property',
        "facebook_user": 'facebookUser'
    }

    def __init__(self,
                 property=None,
                 facebook_user=None):
        """Constructor for the StoreSocial class"""

        # Initialize members of the class
        self.property = property
        self.facebook_user = facebook_user

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        property = None
        if dictionary.get('property') is not None:
            property = [SocialProperty.from_dictionary(x) for x in dictionary.get('property')]
        facebook_user = dictionary.get('facebookUser')

        # Return an object of this model
        return cls(property,
                   facebook_user)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class FirstPartyBranding(object):

    """Implementation of the 'FirstPartyBranding' model.

    Specifies first party branding for a store or other entity.

    Attributes:
        brand (CookiesBrandEnum): Specifies a first-party brand owned or
            operated by Cookies.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "brand": 'brand'
    }

    def __init__(self,
                 brand=None):
        """Constructor for the FirstPartyBranding class"""

        # Initialize members of the class
        self.brand = brand

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        brand = dictionary.get('brand')

        # Return an object of this model
        return cls(brand)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.media_item import MediaItem
from cookiesapi.models.raster_graphic import RasterGraphic


class BrandAsset(object):

    """Implementation of the 'BrandAsset' model.

    Asset linked to a managed brand.

    Attributes:
        raster (RasterGraphic): Rasterized asset.
        vector (MediaItem): Vector asset, if available.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "raster": 'raster',
        "vector": 'vector'
    }

    def __init__(self,
                 raster=None,
                 vector=None):
        """Constructor for the BrandAsset class"""

        # Initialize members of the class
        self.raster = raster
        self.vector = vector

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        raster = RasterGraphic.from_dictionary(dictionary.get('raster')) if dictionary.get('raster') else None
        vector = MediaItem.from_dictionary(dictionary.get('vector')) if dictionary.get('vector') else None

        # Return an object of this model
        return cls(raster,
                   vector)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import os
from cookiesapi.decorators import lazy_property
from cookiesapi.configuration import Configuration
from cookiesapi.configuration import Environment
from cookiesapi.controllers.stores_controller import StoresController
from cookiesapi.controllers.strains_controller import StrainsController
from cookiesapi.controllers.brands_controller import BrandsController


class CookiesapiClient(object):

    @lazy_property
    def stores(self):
        return StoresController(self.config)

    @lazy_property
    def strains(self):
        return StrainsController(self.config)

    @lazy_property
    def brands(self):
        return BrandsController(self.config)

    def __init__(self, timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=[408, 413, 429, 500, 502, 503, 504, 521, 522, 524],
                 retry_methods=['GET', 'PUT'], environment=Environment.SANDBOX,
                 apikey=None, config=None):
        if config is None:
            self.config = Configuration(timeout=timeout,
                                        max_retries=max_retries,
                                        backoff_factor=backoff_factor,
                                        retry_statuses=retry_statuses,
                                        retry_methods=retry_methods,
                                        environment=environment,
                                        apikey=apikey or os.environ.get('COOKIES_APIKEY', ''))
        else:
            self.config = config



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreCapabilityEnum(object):

    """Implementation of the 'StoreCapability' enum.

    Enumerates available store capabilities.

    Attributes:
        PICKUP: Pickup ordering.
        DELIVERY: Delivery ordering.
        CURBSIDE: Curbside pickup ordering.
        LOYALTY: Globally-enrolled loyalty.
        DEBIT: Accepts debit cards.
        MEDICAL: Licensed for medical sales.
        ADULT_USE: Licensed for adult-use sales.

    """

    PICKUP = 'PICKUP'

    DELIVERY = 'DELIVERY'

    CURBSIDE = 'CURBSIDE'

    LOYALTY = 'LOYALTY'

    DEBIT = 'DEBIT'

    MEDICAL = 'MEDICAL'

    ADULT_USE = 'ADULT_USE'



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Address(object):

    """Implementation of the 'Address' model.

    Specifies a street address.

    Attributes:
        region_code (string): ISO country code (3-character).
        postal_code (string): Regional postal code or zip code.
        administrative_area (string): State or province, as a two-letter ISO
            or national code.
        locality (string): City, village, or municipality name.
        address_lines (list of string): Lines for the address itself.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "region_code": 'regionCode',
        "postal_code": 'postalCode',
        "administrative_area": 'administrativeArea',
        "locality": 'locality',
        "address_lines": 'addressLines'
    }

    def __init__(self,
                 region_code=None,
                 postal_code=None,
                 administrative_area=None,
                 locality=None,
                 address_lines=None):
        """Constructor for the Address class"""

        # Initialize members of the class
        self.region_code = region_code
        self.postal_code = postal_code
        self.administrative_area = administrative_area
        self.locality = locality
        self.address_lines = address_lines

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        region_code = dictionary.get('regionCode')
        postal_code = dictionary.get('postalCode')
        administrative_area = dictionary.get('administrativeArea')
        locality = dictionary.get('locality')
        address_lines = dictionary.get('addressLines')

        # Return an object of this model
        return cls(region_code,
                   postal_code,
                   administrative_area,
                   locality,
                   address_lines)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreStatusEnum(object):

    """Implementation of the 'StoreStatus' enum.

    Specifies the current status of a store or D2C property.

    Attributes:
        OPEN: The store or property is open for business.
        CLOSED: The store or property is closed for business.
        PICKUP_ONLY: The store or property is open for pickup only.
        DELIVERY_ONLY: The store or property is open for delivery only.

    """

    OPEN = 'OPEN'

    CLOSED = 'CLOSED'

    PICKUP_ONLY = 'PICKUP_ONLY'

    DELIVERY_ONLY = 'DELIVERY_ONLY'



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SocialProperty(object):

    """Implementation of the 'SocialProperty' model.

    Social media account property.

    Attributes:
        property (string): Social network where this profile exists.
        link (string): Link to this social profile.
        id (string): Unique ID for this social profile, or username.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "property": 'property',
        "link": 'link',
        "id": 'id'
    }

    def __init__(self,
                 property=None,
                 link=None,
                 id=None):
        """Constructor for the SocialProperty class"""

        # Initialize members of the class
        self.property = property
        self.link = link
        self.id = id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        property = dictionary.get('property')
        link = dictionary.get('link')
        id = dictionary.get('id')

        # Return an object of this model
        return cls(property,
                   link,
                   id)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.error_detail import ErrorDetail


class ErrorInfo(object):

    """Implementation of the 'ErrorInfo' model.

    Information describing an error that occurred while transacting with the
    API.

    Attributes:
        faultstring (string): Describes the error with a readable label or
            message.
        detail (ErrorDetail): Further info about the error.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "faultstring": 'faultstring',
        "detail": 'detail'
    }

    def __init__(self,
                 faultstring=None,
                 detail=None):
        """Constructor for the ErrorInfo class"""

        # Initialize members of the class
        self.faultstring = faultstring
        self.detail = detail

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        faultstring = dictionary.get('faultstring')
        detail = ErrorDetail.from_dictionary(dictionary.get('detail')) if dictionary.get('detail') else None

        # Return an object of this model
        return cls(faultstring,
                   detail)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.time_spec import TimeSpec


class HoursRange(object):

    """Implementation of the 'HoursRange' model.

    Range/interval of hours.

    Attributes:
        begin (TimeSpec): Begin time for a given hours range.
        end (TimeSpec): End time for a given hours range.
        status (StoreStatusEnum): Status to apply for a store.
        active (bool): Whether this hours rule is active.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "begin": 'begin',
        "end": 'end',
        "status": 'status',
        "active": 'active'
    }

    def __init__(self,
                 begin=None,
                 end=None,
                 status=None,
                 active=None):
        """Constructor for the HoursRange class"""

        # Initialize members of the class
        self.begin = begin
        self.end = end
        self.status = status
        self.active = active

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        begin = TimeSpec.from_dictionary(dictionary.get('begin')) if dictionary.get('begin') else None
        end = TimeSpec.from_dictionary(dictionary.get('end')) if dictionary.get('end') else None
        status = dictionary.get('status')
        active = dictionary.get('active')

        # Return an object of this model
        return cls(begin,
                   end,
                   status,
                   active)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.brand_asset import BrandAsset
from cookiesapi.models.name import Name
from cookiesapi.models.theme import Theme


class Brand(object):

    """Implementation of the 'Brand' model.

    OpenCannabis brand specification payload.

    Attributes:
        name (Name): Naming information for a brand.
        media (list of BrandAsset): Media/known assets for a brand.
        theme (Theme): Theme information for a brand.
        slug (string): Slug assigned to this brand.
        link (string): Full URL for this brand.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "media": 'media',
        "theme": 'theme',
        "slug": 'slug',
        "link": 'link'
    }

    def __init__(self,
                 name=None,
                 media=None,
                 theme=None,
                 slug=None,
                 link=None):
        """Constructor for the Brand class"""

        # Initialize members of the class
        self.name = name
        self.media = media
        self.theme = theme
        self.slug = slug
        self.link = link

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = Name.from_dictionary(dictionary.get('name')) if dictionary.get('name') else None
        media = None
        if dictionary.get('media') is not None:
            media = [BrandAsset.from_dictionary(x) for x in dictionary.get('media')]
        theme = Theme.from_dictionary(dictionary.get('theme')) if dictionary.get('theme') else None
        slug = dictionary.get('slug')
        link = dictionary.get('link')

        # Return an object of this model
        return cls(name,
                   media,
                   theme,
                   slug,
                   link)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.media_item import MediaItem


class RasterGraphic(object):

    """Implementation of the 'RasterGraphic' model.

    Describes a rasterized asset which may carry variants with enhanced
    resolution.

    Attributes:
        standard (MediaItem): Standard-size graphic asset.
        retina (MediaItem): Retina-size graphic asset.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "standard": 'standard',
        "retina": 'retina'
    }

    def __init__(self,
                 standard=None,
                 retina=None):
        """Constructor for the RasterGraphic class"""

        # Initialize members of the class
        self.standard = standard
        self.retina = retina

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        standard = MediaItem.from_dictionary(dictionary.get('standard')) if dictionary.get('standard') else None
        retina = MediaItem.from_dictionary(dictionary.get('retina')) if dictionary.get('retina') else None

        # Return an object of this model
        return cls(standard,
                   retina)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.brand_spec import BrandSpec
from cookiesapi.models.breeder import Breeder
from cookiesapi.models.material_info import MaterialInfo
from cookiesapi.models.name import Name
from cookiesapi.models.strain_media import StrainMedia
from cookiesapi.models.strain_social import StrainSocial
from cookiesapi.models.theme import Theme


class Strain(object):

    """Implementation of the 'Strain' model.

    Describes a Cookies strain.

    Attributes:
        id (string): Unique ID assigned to this strain.
        slug (string): Unique URL slug assigned to this strain.
        name (Name): Name of the strain.
        brand (BrandSpec): Brand info for the strain.
        species (SpeciesEnum): Species for the strain.
        media (StrainMedia): Media assigned to a strain.
        material (MaterialInfo): Material info for a strain.
        breeder (list of Breeder): Breeder info for a strain.
        visible (bool): Whether a strain is visible.
        social (StrainSocial): Social information for a strain.
        featured (bool): Whether a strain is featured.
        exclusive (bool): Whether a strain is exclusive to Cookies.
        theme (Theme): Theme information for a strain.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "slug": 'slug',
        "name": 'name',
        "brand": 'brand',
        "species": 'species',
        "media": 'media',
        "material": 'material',
        "breeder": 'breeder',
        "visible": 'visible',
        "social": 'social',
        "featured": 'featured',
        "exclusive": 'exclusive',
        "theme": 'theme'
    }

    def __init__(self,
                 id=None,
                 slug=None,
                 name=None,
                 brand=None,
                 species=None,
                 media=None,
                 material=None,
                 breeder=None,
                 visible=None,
                 social=None,
                 featured=None,
                 exclusive=None,
                 theme=None):
        """Constructor for the Strain class"""

        # Initialize members of the class
        self.id = id
        self.slug = slug
        self.name = name
        self.brand = brand
        self.species = species
        self.media = media
        self.material = material
        self.breeder = breeder
        self.visible = visible
        self.social = social
        self.featured = featured
        self.exclusive = exclusive
        self.theme = theme

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        slug = dictionary.get('slug')
        name = Name.from_dictionary(dictionary.get('name')) if dictionary.get('name') else None
        brand = BrandSpec.from_dictionary(dictionary.get('brand')) if dictionary.get('brand') else None
        species = dictionary.get('species')
        media = StrainMedia.from_dictionary(dictionary.get('media')) if dictionary.get('media') else None
        material = MaterialInfo.from_dictionary(dictionary.get('material')) if dictionary.get('material') else None
        breeder = None
        if dictionary.get('breeder') is not None:
            breeder = [Breeder.from_dictionary(x) for x in dictionary.get('breeder')]
        visible = dictionary.get('visible')
        social = StrainSocial.from_dictionary(dictionary.get('social')) if dictionary.get('social') else None
        featured = dictionary.get('featured')
        exclusive = dictionary.get('exclusive')
        theme = Theme.from_dictionary(dictionary.get('theme')) if dictionary.get('theme') else None

        # Return an object of this model
        return cls(id,
                   slug,
                   name,
                   brand,
                   species,
                   media,
                   material,
                   breeder,
                   visible,
                   social,
                   featured,
                   exclusive,
                   theme)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from cookiesapi.api_helper import APIHelper
from cookiesapi.controllers.stores_controller import StoresController


class StoresControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(StoresControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = StoresController(cls.config, cls.response_catcher)

    # Fetch a generic list of all stores.
    def test_list_stores(self):
        # Parameters for the API call
        brand = None

        # Perform the API call through the SDK function
        result = self.controller.list_stores(brand)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # List stores, filtered by brand COOKIES.
    def test_list_stores_cookies(self):
        # Parameters for the API call
        brand = 'COOKIES'

        # Perform the API call through the SDK function
        result = self.controller.list_stores(brand)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)

    # List stores, filtered by brand LEMONNADE.
    def test_list_stores_lemonnade(self):
        # Parameters for the API call
        brand = 'LEMONNADE'

        # Perform the API call through the SDK function
        result = self.controller.list_stores(brand)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 200)




# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.store import Store


class StoreList(object):

    """Implementation of the 'StoreList' model.

    Describes a list of store records.

    Attributes:
        store (list of Store): List of stores.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "store": 'store'
    }

    def __init__(self,
                 store=None):
        """Constructor for the StoreList class"""

        # Initialize members of the class
        self.store = store

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        store = None
        if dictionary.get('store') is not None:
            store = [Store.from_dictionary(x) for x in dictionary.get('store')]

        # Return an object of this model
        return cls(store)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.address import Address
from cookiesapi.models.geo import Geo


class Location(object):

    """Implementation of the 'Location' model.

    Describes physical location info.

    Attributes:
        address (Address): Street address.
        geo (Geo): Geo point or boundary.
        hash (string): Geo hash.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "address": 'address',
        "geo": 'geo',
        "hash": 'hash'
    }

    def __init__(self,
                 address=None,
                 geo=None,
                 hash=None):
        """Constructor for the Location class"""

        # Initialize members of the class
        self.address = address
        self.geo = geo
        self.hash = hash

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        address = Address.from_dictionary(dictionary.get('address')) if dictionary.get('address') else None
        geo = Geo.from_dictionary(dictionary.get('geo')) if dictionary.get('geo') else None
        hash = dictionary.get('hash')

        # Return an object of this model
        return cls(address,
                   geo,
                   hash)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.color import Color


class Theme(object):

    """Implementation of the 'Theme' model.

    OpenCannabis record which describes theming information for a given
    record.

    Attributes:
        primary (Color): Primary color.
        secondary (Color): Secondary color.
        alert (Color): Alert color.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "primary": 'primary',
        "secondary": 'secondary',
        "alert": 'alert'
    }

    def __init__(self,
                 primary=None,
                 secondary=None,
                 alert=None):
        """Constructor for the Theme class"""

        # Initialize members of the class
        self.primary = primary
        self.secondary = secondary
        self.alert = alert

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        primary = Color.from_dictionary(dictionary.get('primary')) if dictionary.get('primary') else None
        secondary = Color.from_dictionary(dictionary.get('secondary')) if dictionary.get('secondary') else None
        alert = Color.from_dictionary(dictionary.get('alert')) if dictionary.get('alert') else None

        # Return an object of this model
        return cls(primary,
                   secondary,
                   alert)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.first_party_branding import FirstPartyBranding


class StoreBranding(object):

    """Implementation of the 'StoreBranding' model.

    Branding information for a physical retail store.

    Attributes:
        first_party (FirstPartyBranding): Specifies the first-party brand for
            a store.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "first_party": 'firstParty'
    }

    def __init__(self,
                 first_party=None):
        """Constructor for the StoreBranding class"""

        # Initialize members of the class
        self.first_party = first_party

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        first_party = FirstPartyBranding.from_dictionary(dictionary.get('firstParty')) if dictionary.get('firstParty') else None

        # Return an object of this model
        return cls(first_party)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.contact import Contact
from cookiesapi.models.hours import Hours
from cookiesapi.models.location import Location
from cookiesapi.models.name import Name
from cookiesapi.models.store_branding import StoreBranding
from cookiesapi.models.store_key import StoreKey
from cookiesapi.models.store_media import StoreMedia
from cookiesapi.models.store_ordering import StoreOrdering
from cookiesapi.models.store_social import StoreSocial
from cookiesapi.models.store_web import StoreWeb


class Store(object):

    """Implementation of the 'Store' model.

    Specifies a physical retail location owned or operated by Cookies, or
    partnering with Cookies to sell products made by Cookies.

    Attributes:
        key (StoreKey): Describes unique key information for a retail store.
        live (bool): Specifies whether this retail location is live.
        slug (string): Specifies the unique URL slug for this store.
        name (Name): Specifies naming and labeling information for a Cookies
            store.
        mtype (StoreTypeEnum): Specifies the type for a retail store.
        location (Location): Specifies location information for a retail
            store.
        contact (Contact): Specifies contact information for a retail store.
        capability (list of StoreCapabilityEnum): Specifies documented
            capabilities at a retail store.
        hours (Hours): Specifies regular and special hours for a retail
            store.
        social (StoreSocial): Specifies social media accounts for a retail
            store.
        media (StoreMedia): Specifies photography and other assets for a
            retail store.
        web (StoreWeb): Specifies website and link information for a retail
            store.
        branding (StoreBranding): Specifies branding information for a retail
            store.
        ordering (StoreOrdering): Specifies online ordering information for a
            retail store.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key": 'key',
        "live": 'live',
        "slug": 'slug',
        "name": 'name',
        "mtype": 'type',
        "location": 'location',
        "contact": 'contact',
        "capability": 'capability',
        "hours": 'hours',
        "social": 'social',
        "media": 'media',
        "web": 'web',
        "branding": 'branding',
        "ordering": 'ordering'
    }

    def __init__(self,
                 key=None,
                 live=None,
                 slug=None,
                 name=None,
                 mtype=None,
                 location=None,
                 contact=None,
                 capability=None,
                 hours=None,
                 social=None,
                 media=None,
                 web=None,
                 branding=None,
                 ordering=None):
        """Constructor for the Store class"""

        # Initialize members of the class
        self.key = key
        self.live = live
        self.slug = slug
        self.name = name
        self.mtype = mtype
        self.location = location
        self.contact = contact
        self.capability = capability
        self.hours = hours
        self.social = social
        self.media = media
        self.web = web
        self.branding = branding
        self.ordering = ordering

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = StoreKey.from_dictionary(dictionary.get('key')) if dictionary.get('key') else None
        live = dictionary.get('live')
        slug = dictionary.get('slug')
        name = Name.from_dictionary(dictionary.get('name')) if dictionary.get('name') else None
        mtype = dictionary.get('type')
        location = Location.from_dictionary(dictionary.get('location')) if dictionary.get('location') else None
        contact = Contact.from_dictionary(dictionary.get('contact')) if dictionary.get('contact') else None
        capability = dictionary.get('capability')
        hours = Hours.from_dictionary(dictionary.get('hours')) if dictionary.get('hours') else None
        social = StoreSocial.from_dictionary(dictionary.get('social')) if dictionary.get('social') else None
        media = StoreMedia.from_dictionary(dictionary.get('media')) if dictionary.get('media') else None
        web = StoreWeb.from_dictionary(dictionary.get('web')) if dictionary.get('web') else None
        branding = StoreBranding.from_dictionary(dictionary.get('branding')) if dictionary.get('branding') else None
        ordering = StoreOrdering.from_dictionary(dictionary.get('ordering')) if dictionary.get('ordering') else None

        # Return an object of this model
        return cls(key,
                   live,
                   slug,
                   name,
                   mtype,
                   location,
                   contact,
                   capability,
                   hours,
                   social,
                   media,
                   web,
                   branding,
                   ordering)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreOrdering(object):

    """Implementation of the 'StoreOrdering' model.

    Describes order submission and menu information for a given Cookies
    store.

    Attributes:
        platform (string): Ordering platform in use by a Cookies store.
        store_id (string): Ordering platform ID in use by a Cookies store
            (public).
        enabled (bool): Whether online ordering is enabled for a given Cookies
            store.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "platform": 'platform',
        "store_id": 'storeId',
        "enabled": 'enabled'
    }

    def __init__(self,
                 platform=None,
                 store_id=None,
                 enabled=None):
        """Constructor for the StoreOrdering class"""

        # Initialize members of the class
        self.platform = platform
        self.store_id = store_id
        self.enabled = enabled

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        platform = dictionary.get('platform')
        store_id = dictionary.get('storeId')
        enabled = dictionary.get('enabled')

        # Return an object of this model
        return cls(platform,
                   store_id,
                   enabled)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class MediaType(object):

    """Implementation of the 'MediaType' model.

    Specifies type information for a media asset.

    Attributes:
        image_type (string): Specifies an image format, as applicable.
        kind (string): Specifies the broad "kind" of media.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "image_type": 'imageType',
        "kind": 'kind'
    }

    def __init__(self,
                 image_type=None,
                 kind=None):
        """Constructor for the MediaType class"""

        # Initialize members of the class
        self.image_type = image_type
        self.kind = kind

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        image_type = dictionary.get('imageType')
        kind = dictionary.get('kind')

        # Return an object of this model
        return cls(image_type,
                   kind)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.media_item import MediaItem


class ResponsiveGraphic(object):

    """Implementation of the 'ResponsiveGraphic' model.

    Describes a rasterized responsive graphic asset.

    Attributes:
        portrait (MediaItem): Portrait-style asset.
        landscape (MediaItem): Landscape-style asset.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "portrait": 'portrait',
        "landscape": 'landscape'
    }

    def __init__(self,
                 portrait=None,
                 landscape=None):
        """Constructor for the ResponsiveGraphic class"""

        # Initialize members of the class
        self.portrait = portrait
        self.landscape = landscape

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        portrait = MediaItem.from_dictionary(dictionary.get('portrait')) if dictionary.get('portrait') else None
        landscape = MediaItem.from_dictionary(dictionary.get('landscape')) if dictionary.get('landscape') else None

        # Return an object of this model
        return cls(portrait,
                   landscape)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.brand import Brand
from cookiesapi.models.media_item import MediaItem


class BrandSpec(object):

    """Implementation of the 'BrandSpec' model.

    Descriptor which specifies a first-party or third-party brand.

    Attributes:
        id (string): System ID for a brand. Do not key against this: it is
            guaranteed to change.
        bid (string): Assigned ID for this brand. Immutable and reliable.
        brand (Brand): OpenCannabis payload describing this brand.
        owned (bool): Whether this brand is owned by Cookies.
        icon (MediaItem): Media/asset icon for this brand.
        negative_icon (MediaItem): Negative-mode icon for this brand.
        live (bool): Whether this brand is live.
        sort_weight (int): Sort weight of this brand.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "bid": 'bid',
        "brand": 'brand',
        "owned": 'owned',
        "icon": 'icon',
        "negative_icon": 'negativeIcon',
        "live": 'live',
        "sort_weight": 'sortWeight'
    }

    def __init__(self,
                 id=None,
                 bid=None,
                 brand=None,
                 owned=None,
                 icon=None,
                 negative_icon=None,
                 live=None,
                 sort_weight=None):
        """Constructor for the BrandSpec class"""

        # Initialize members of the class
        self.id = id
        self.bid = bid
        self.brand = brand
        self.owned = owned
        self.icon = icon
        self.negative_icon = negative_icon
        self.live = live
        self.sort_weight = sort_weight

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        bid = dictionary.get('bid')
        brand = Brand.from_dictionary(dictionary.get('brand')) if dictionary.get('brand') else None
        owned = dictionary.get('owned')
        icon = MediaItem.from_dictionary(dictionary.get('icon')) if dictionary.get('icon') else None
        negative_icon = MediaItem.from_dictionary(dictionary.get('negativeIcon')) if dictionary.get('negativeIcon') else None
        live = dictionary.get('live')
        sort_weight = dictionary.get('sortWeight')

        # Return an object of this model
        return cls(id,
                   bid,
                   brand,
                   owned,
                   icon,
                   negative_icon,
                   live,
                   sort_weight)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.dual_format_graphic import DualFormatGraphic
from cookiesapi.models.media_item import MediaItem
from cookiesapi.models.responsive_graphic import ResponsiveGraphic


class StrainMedia(object):

    """Implementation of the 'StrainMedia' model.

    Specifies media/assets attached to a Cookies strain.

    Attributes:
        artwork (DualFormatGraphic): Artwork imagery for a strain.
        head (MediaItem): Headshot images for a strain.
        packaging (MediaItem): Packaging photography for a strain.
        material (list of MediaItem): Material photography for a strain.
        lockup (DualFormatGraphic): Lockup artwork for a strain.
        card (MediaItem): Card artwork for a strain.
        menu (MediaItem): Menu artwork for a strain.
        macro (list of MediaItem): Macro flower photography for a strain.
        cultivation (list of MediaItem): Late-stage cultivation photography
            for a strain.
        lifestyle (list of MediaItem): Lifestyle photography associated with a
            strain.
        tile (MediaItem): Tile graphic associated with a strain.
        masthead (ResponsiveGraphic): Masthead images associated with a
            strain.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "artwork": 'artwork',
        "head": 'head',
        "packaging": 'packaging',
        "material": 'material',
        "lockup": 'lockup',
        "card": 'card',
        "menu": 'menu',
        "macro": 'macro',
        "cultivation": 'cultivation',
        "lifestyle": 'lifestyle',
        "tile": 'tile',
        "masthead": 'masthead'
    }

    def __init__(self,
                 artwork=None,
                 head=None,
                 packaging=None,
                 material=None,
                 lockup=None,
                 card=None,
                 menu=None,
                 macro=None,
                 cultivation=None,
                 lifestyle=None,
                 tile=None,
                 masthead=None):
        """Constructor for the StrainMedia class"""

        # Initialize members of the class
        self.artwork = artwork
        self.head = head
        self.packaging = packaging
        self.material = material
        self.lockup = lockup
        self.card = card
        self.menu = menu
        self.macro = macro
        self.cultivation = cultivation
        self.lifestyle = lifestyle
        self.tile = tile
        self.masthead = masthead

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        artwork = DualFormatGraphic.from_dictionary(dictionary.get('artwork')) if dictionary.get('artwork') else None
        head = MediaItem.from_dictionary(dictionary.get('head')) if dictionary.get('head') else None
        packaging = MediaItem.from_dictionary(dictionary.get('packaging')) if dictionary.get('packaging') else None
        material = None
        if dictionary.get('material') is not None:
            material = [MediaItem.from_dictionary(x) for x in dictionary.get('material')]
        lockup = DualFormatGraphic.from_dictionary(dictionary.get('lockup')) if dictionary.get('lockup') else None
        card = MediaItem.from_dictionary(dictionary.get('card')) if dictionary.get('card') else None
        menu = MediaItem.from_dictionary(dictionary.get('menu')) if dictionary.get('menu') else None
        macro = None
        if dictionary.get('macro') is not None:
            macro = [MediaItem.from_dictionary(x) for x in dictionary.get('macro')]
        cultivation = None
        if dictionary.get('cultivation') is not None:
            cultivation = [MediaItem.from_dictionary(x) for x in dictionary.get('cultivation')]
        lifestyle = None
        if dictionary.get('lifestyle') is not None:
            lifestyle = [MediaItem.from_dictionary(x) for x in dictionary.get('lifestyle')]
        tile = MediaItem.from_dictionary(dictionary.get('tile')) if dictionary.get('tile') else None
        masthead = ResponsiveGraphic.from_dictionary(dictionary.get('masthead')) if dictionary.get('masthead') else None

        # Return an object of this model
        return cls(artwork,
                   head,
                   packaging,
                   material,
                   lockup,
                   card,
                   menu,
                   macro,
                   cultivation,
                   lifestyle,
                   tile,
                   masthead)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from cookiesapi.api_helper import APIHelper
import cookiesapi.exceptions.api_exception
from cookiesapi.models.error_info import ErrorInfo


class FaultResponseException(cookiesapi.exceptions.api_exception.APIException):
    def __init__(self, reason, response):
        """Constructor for the FaultResponseException class

        Args:
            reason (string): The reason (or error message) for the Exception
                to be raised.
            response (HttpResponse): The HttpResponse of the API call.

        """
        super(FaultResponseException, self).__init__(reason, response)
        dictionary = APIHelper.json_deserialize(self.response.text)
        if isinstance(dictionary, dict):
            self.unbox(dictionary)

    def unbox(self, dictionary):
        """Populates the properties of this object by extracting them from a dictionary.

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        """
        self.fault = ErrorInfo.from_dictionary(dictionary.get('fault')) if dictionary.get('fault') else None



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.regular_hours import RegularHours


class Hours(object):

    """Implementation of the 'Hours' model.

    Describes regular and special store hours.

    Attributes:
        regular (list of RegularHours): Specifies regular store hours.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "regular": 'regular'
    }

    def __init__(self,
                 regular=None):
        """Constructor for the Hours class"""

        # Initialize members of the class
        self.regular = regular

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        regular = None
        if dictionary.get('regular') is not None:
            regular = [RegularHours.from_dictionary(x) for x in dictionary.get('regular')]

        # Return an object of this model
        return cls(regular)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.media_item import MediaItem


class StoreMedia(object):

    """Implementation of the 'StoreMedia' model.

    Photography and other media related to a first-party Cookies store.

    Attributes:
        facade (list of MediaItem): Facade photography of a Cookies store.
        inside (list of MediaItem): Inside photography of a Cookies store.
        masthead (list of MediaItem): Masthead (featured) photography for a
            Cookies store.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "facade": 'facade',
        "inside": 'inside',
        "masthead": 'masthead'
    }

    def __init__(self,
                 facade=None,
                 inside=None,
                 masthead=None):
        """Constructor for the StoreMedia class"""

        # Initialize members of the class
        self.facade = facade
        self.inside = inside
        self.masthead = masthead

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        facade = None
        if dictionary.get('facade') is not None:
            facade = [MediaItem.from_dictionary(x) for x in dictionary.get('facade')]
        inside = None
        if dictionary.get('inside') is not None:
            inside = [MediaItem.from_dictionary(x) for x in dictionary.get('inside')]
        masthead = None
        if dictionary.get('masthead') is not None:
            masthead = [MediaItem.from_dictionary(x) for x in dictionary.get('masthead')]

        # Return an object of this model
        return cls(facade,
                   inside,
                   masthead)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from cookiesapi.api_helper import APIHelper
from cookiesapi.controllers.brands_controller import BrandsController


class BrandsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(BrandsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = BrandsController(cls.config, cls.response_catcher)




# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.brand_spec import BrandSpec
from cookiesapi.models.media_item import MediaItem
from cookiesapi.models.name import Name


class Breeder(object):

    """Implementation of the 'Breeder' model.

    Information about a Cookies in-house breeder or partner breeder.

    Attributes:
        id (string): Unique ID assigned to a breeder. Do not key against this:
            it is guaranteed to change.
        slug (string): Unique slug assigned to a breeder. Typically assigned
            if there is no linked brand. If a linked brand is present, this
            field takes precedence, should any value be present.
        name (Name): Naming info for a breeder. Typically assigned if there is
            no linked brand. If a linked brand is present, this field takes
            precedence, should any value be present.
        brand (BrandSpec): Brand associated with a breeder, if applicable.
        logo (MediaItem): Logo for a breeder, if available.
        in_house (bool): Whether this breeder is considered "in-house".

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "slug": 'slug',
        "name": 'name',
        "brand": 'brand',
        "logo": 'logo',
        "in_house": 'inHouse'
    }

    def __init__(self,
                 id=None,
                 slug=None,
                 name=None,
                 brand=None,
                 logo=None,
                 in_house=None):
        """Constructor for the Breeder class"""

        # Initialize members of the class
        self.id = id
        self.slug = slug
        self.name = name
        self.brand = brand
        self.logo = logo
        self.in_house = in_house

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        slug = dictionary.get('slug')
        name = Name.from_dictionary(dictionary.get('name')) if dictionary.get('name') else None
        brand = BrandSpec.from_dictionary(dictionary.get('brand')) if dictionary.get('brand') else None
        logo = MediaItem.from_dictionary(dictionary.get('logo')) if dictionary.get('logo') else None
        in_house = dictionary.get('inHouse')

        # Return an object of this model
        return cls(id,
                   slug,
                   name,
                   brand,
                   logo,
                   in_house)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.media_key import MediaKey
from cookiesapi.models.media_type import MediaType


class MediaItem(object):

    """Implementation of the 'MediaItem' model.

    Reference to a known media asset.

    Attributes:
        key (MediaKey): Unique key assigned to, or generated for, this asset.
        mtype (MediaType): Type specifications for this asset.
        serving_uri (string): Serving URI, if available, for this asset.
        uri (string): Origin URI for this asset.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "key": 'key',
        "mtype": 'type',
        "serving_uri": 'servingUri',
        "uri": 'uri'
    }

    def __init__(self,
                 key=None,
                 mtype=None,
                 serving_uri=None,
                 uri=None):
        """Constructor for the MediaItem class"""

        # Initialize members of the class
        self.key = key
        self.mtype = mtype
        self.serving_uri = serving_uri
        self.uri = uri

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        key = MediaKey.from_dictionary(dictionary.get('key')) if dictionary.get('key') else None
        mtype = MediaType.from_dictionary(dictionary.get('type')) if dictionary.get('type') else None
        serving_uri = dictionary.get('servingUri')
        uri = dictionary.get('uri')

        # Return an object of this model
        return cls(key,
                   mtype,
                   serving_uri,
                   uri)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreKey(object):

    """Implementation of the 'StoreKey' model.

    Specifies key information which uniquely identifies a physical retail
    store.

    Attributes:
        id (string): Unique ID for a store.
        code (string): First-party store code.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "code": 'code'
    }

    def __init__(self,
                 id=None,
                 code=None):
        """Constructor for the StoreKey class"""

        # Initialize members of the class
        self.id = id
        self.code = code

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('id')
        code = dictionary.get('code')

        # Return an object of this model
        return cls(id,
                   code)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SpeciesEnum(object):

    """Implementation of the 'Species' enum.

    OpenCannabis species specifier.

    Attributes:
        UNSPECIFIED: The item has no species, or the species value is not
            applicable.
        SATIVA: The item is assigned SATIVA species.
        HYBRID_SATIVA: The item is assigned HYBRID species that leans SATIVA.
        HYBRID: The item is assigned pure HYBRID species.
        HYBRID_INDICA: The item is assigned HYBRID species that leans INDICA.
        INDICA: The item is assigned INDICA species.

    """

    UNSPECIFIED = 'UNSPECIFIED'

    SATIVA = 'SATIVA'

    HYBRID_SATIVA = 'HYBRID_SATIVA'

    HYBRID = 'HYBRID'

    HYBRID_INDICA = 'HYBRID_INDICA'

    INDICA = 'INDICA'



# -*- coding: utf-8 -*-

import sys
from setuptools import setup, find_packages


def readfile(file):
    if sys.version_info[0] < 3:
        with open(file, 'r') as fh:
            return fh.read()
    else:
        with open(file, 'r', encoding='utf-8') as fh:
            return fh.read()

long_description = readfile('README.md')
libversion = readfile('.version')
deps = readfile('requirements.txt')
devdeps = readfile('dev-requirements.txt')


setup(
    name='cookiesapi',
    version=libversion,
    description='Python SDK for working with Cookies APIs.',
    long_description=long_description,
    long_description_content_type="text/markdown",
    author='Eng@Cookies',
    author_email='engineering@cookiescalifornia.com',
    url='https://cookies.dev',
    packages=find_packages(),
    install_requires=filter(lambda x: x != '', deps.split('\n')),
    tests_require=filter(lambda x: x != '', devdeps.split('\n')),
    test_suite = 'nose.collector'
)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class MaterialInfo(object):

    """Implementation of the 'MaterialInfo' model.

    Describes material or operational regarding about a Cookies strain.

    Attributes:
        breeder (string): Breeder(s) who produced a strain.
        aroma (string): Aroma notes for a strain.
        flavor (string): Flavor notes for a strain.
        experience (string): Experience notes for a strain.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "breeder": 'breeder',
        "aroma": 'aroma',
        "flavor": 'flavor',
        "experience": 'experience'
    }

    def __init__(self,
                 breeder=None,
                 aroma=None,
                 flavor=None,
                 experience=None):
        """Constructor for the MaterialInfo class"""

        # Initialize members of the class
        self.breeder = breeder
        self.aroma = aroma
        self.flavor = flavor
        self.experience = experience

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        breeder = dictionary.get('breeder')
        aroma = dictionary.get('aroma')
        flavor = dictionary.get('flavor')
        experience = dictionary.get('experience')

        # Return an object of this model
        return cls(breeder,
                   aroma,
                   flavor,
                   experience)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from cookiesapi.models.hours_range import HoursRange


class RegularHours(object):

    """Implementation of the 'RegularHours' model.

    Describes regular store hours.

    Attributes:
        day (list of string): Days which a given regular hours rule applies
            to.
        hours (list of HoursRange): Hours to apply on the specified days.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "day": 'day',
        "hours": 'hours'
    }

    def __init__(self,
                 day=None,
                 hours=None):
        """Constructor for the RegularHours class"""

        # Initialize members of the class
        self.day = day
        self.hours = hours

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        day = dictionary.get('day')
        hours = None
        if dictionary.get('hours') is not None:
            hours = [HoursRange.from_dictionary(x) for x in dictionary.get('hours')]

        # Return an object of this model
        return cls(day,
                   hours)



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class StoreTypeEnum(object):

    """Implementation of the 'StoreType' enum.

    Enumerates types of Cookies stores.

    Attributes:
        FIRST_PARTY: Describes a first-party Cookies store.
        THIRD_PARTY: Describes a third-party store that carries Cookies
            products.
        NETWORK: Describes a store affiliated with Cookies.

    """

    FIRST_PARTY = 'FIRST_PARTY'

    THIRD_PARTY = 'THIRD_PARTY'

    NETWORK = 'NETWORK'



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from cookiesapi.api_helper import APIHelper
from cookiesapi.configuration import Server
from cookiesapi.controllers.base_controller import BaseController
from cookiesapi.models.brand_list import BrandList


class BrandsController(BaseController):

    """A Controller to access Endpoints in the cookiesapi API."""

    def __init__(self, config, call_back=None):
        super(BrandsController, self).__init__(config, call_back)

    def list_brands(self):
        """Does a GET request to /app/v1/cookies.App/Brands.

        Retrieve a list of Cookies family brands.

        Returns:
            BrandList: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/app/v1/cookies.App/Brands'
        _query_builder = self.config.get_base_uri(Server.DEFAULT)
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json;charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, BrandList.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
cookiesapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CookiesBrandEnum(object):

    """Implementation of the 'CookiesBrand' enum.

    Specifies 1st-party store brands.

    Attributes:
        COOKIES: Specifies the brand "Cookies".
        LEMONNADE: Specifies the brand "Lemonnade".

    """

    COOKIES = 'COOKIES'

    LEMONNADE = 'LEMONNADE'
